function displayV (Vx, Vy, step, scale)
% displayV(Vx, Vy, step, scale)
% displays the velocity field whose horizontal and vertical components
% are stored in the input matrices Vx and Vy. The quiver function is used
% to display the velocities as vectors, and step is the gap between rows
% and columns where a velocity vector is displayed

% velocity data is placed in vectors containing x and y coordinates,
% and x and y components of motion, to use with the quiver function
[rows, cols] = size(Vx);
num = sum(sum((abs(Vx) > 0.0) | (abs(Vy) > 0.0)));  
xc = zeros(1, num);
yc = zeros(1, num);
velx = zeros(1, num);
vely = zeros(1, num);
index = 1;
for j = 1:step:cols
    for i = 1:step:rows
        if ((abs(Vx(i,j)) > 0.0) || (abs(Vy(i,j)) > 0.0))
            xc(index) = j;
            yc(index) = i;
            velx(index) = Vx(i,j);
            vely(index) = Vy(i,j);
            index = index + 1;
        end
    end
end
% coordinates are adjusted so that x increases left to right, y increases 
% top to bottom, Vx > 0 is motion to the right, Vy > 0 is motion downwards
quiver(xc, yc, velx, vely, scale, 'r', 'LineWidth', 2);
